Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(851)

Unified Diff: content/public/browser/navigation_controller.h

Issue 10704048: [RDS] Reloads a page using the original request URL (Closed) Base URL: http://git.chromium.org/chromium/src.git@master
Patch Set: Created 8 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/public/browser/navigation_controller.h
diff --git a/content/public/browser/navigation_controller.h b/content/public/browser/navigation_controller.h
index 28d20d30b73a1ba48d4efeda07103c7f585fb631..6ee0e09a7424a36e74ea5832e6cfa84d5d7d2c58 100644
--- a/content/public/browser/navigation_controller.h
+++ b/content/public/browser/navigation_controller.h
@@ -32,9 +32,10 @@ struct Referrer;
class NavigationController {
public:
enum ReloadType {
- NO_RELOAD, // Normal load.
- RELOAD, // Normal (cache-validating) reload.
- RELOAD_IGNORING_CACHE // Reload bypassing the cache, aka shift-reload.
+ NO_RELOAD, // Normal load.
+ RELOAD, // Normal (cache-validating) reload.
+ RELOAD_IGNORING_CACHE, // Reload bypassing the cache (shift-reload).
+ RELOAD_ORIGINAL_REQUEST_URL // Reload using the original request URL.
};
// Creates a navigation entry and translates the virtual url to a real one.
@@ -219,6 +220,11 @@ class NavigationController {
// Like Reload(), but don't use caches (aka "shift-reload").
virtual void ReloadIgnoringCache(bool check_for_repost) = 0;
+ // Reloads the current entry using the original URL used to create it. This
+ // is used for cases where the user wants to refresh a page using a different
+ // user agent after following a redirect.
+ virtual void ReloadOriginalRequestURL() = 0;
jam 2012/06/29 21:46:17 is this being called from code that's outside of c
gone 2012/06/29 21:59:10 It hasn't been upstreamed, yet; the only place it'
jam 2012/06/29 22:58:58 ok, in that case, it should be on the impl only (s
gone 2012/07/03 00:07:47 Moved it over to the Impl.
+
// Removing of entries -------------------------------------------------------
// Removes the entry at the specified |index|. This call dicards any pending

Powered by Google App Engine
This is Rietveld 408576698